# 📜 Contribution Guidelines
### for Awesome Design Tools, Plugins, Design Conferences, UI Kits

If you would like to contribute, just send a Pull Request. Please follow these rules:
* Search previous suggestions before making a new one to prevent duplicates.
* Try to make your Pull Request descriptive and check all questions in the PR template.
* End all descriptions with a full stop/period and remove trailing whitespace.
* Check spelling and grammar.
* Please, add appropriate tags.
* If you submit a design tool to the Awesome Design Tools repo, please put the tool in the alphabetical order. All tools are great, so we want to treat them equally.
* If you submit a design conference to the Awesome Design Conferences repo, please put the conference according to the date. The earliest conference should be first. It's just easy to perceive.
* New categories are welcomed if you have 2+ tools, plugins, UI Kits, or conferences to submit to that category.


## 📍 One tool, plugin, UI Kit or conference can go only to one category
For example, in Awesome Design Tools, every category presents some design work or task. Many design tools allow us to solve multiple tasks. But in this list, one tool with full description & link is always submitted only to one category (section). Why do so? Because we want to avoid many duplications and misunderstanding around tool functionality.

However, if the tool can be used for another task, just mention the tool name in the additional sentence at the end of another category, like here: `You can also do prototyping with Figma, Adobe XD, Sketch and InVision Studio, which are mentioned in the UI Design Tools section.`


## 🔗 Link Format
* Please, use the following format for the links in Pull Requests: ``[Tool\Plugin\UI Kit\Conference](link) — description``. The description should start from the lower-case letter unless it's starting with the tool name.

* Please, add the appropriate labels:
  * ![free.svg](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/free.svg) for free tools. **Free means** entirely free tools, not freemium or those which have free trial, free limited functionality. For adding label just copy & paste the following snippet: ``![free.svg](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/free.svg)``
  * ![open-source.svg](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/open-source.svg) for open-source tools. Use the following snippet: ``![open-source.svg](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/open-source.svg)``
  * ![mac.svg](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/mac.svg) for Mac only tools. Use the following snippet: ``![mac.svg](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/mac.svg)``
  * ![Sketch](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/sketch.svg)  for Sketch plugins and UI Kits: `![Sketch](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/sketch.svg)`
  * ![Adobe XD](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/adobe-xd.svg)  for XD plugins and UI Kits: `![Adobe XD](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/adobe-xd.svg)`
  * ![Figma](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/figma.svg)  for Figma plugins and UI Kits: `![Figma](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/figma.svg)`
  * ![InVision Stusio](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/invision-studio.svg)  for InVision Studio: `![InVision Stusio](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/invision-studio.svg)`
  * ![Mobile](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/smartphone-mobile-phone-svgrepo-com.svg)  for Mobile UI Kits: `![Mobile](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/smartphone-mobile-phone-svgrepo-com.svg)`
  * ![Web](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/web.svg)  for UI Kits which can be used for websites, web app and other web products: `![Web](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/web.svg)`
  * ![Desktop](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/desktop.svg)  for desktop UI Kits: `![Desktop](https://github.com/LisaDziuba/Awesome-Design-Tools/blob/master/Media/desktop.svg)`


## Review Workflow  
We will do our best to review your submission as soon as we can. Please, consider that we have a full-time job in our startup :) Your contribution might be rejected if the tool, UI Kit, plugin or conferences didn't pass our curation. Of course, this is very subjective and if you think we are being unfair, do let us know.
